enumStatementRule
enum StatementRule: string
Public API: explicitly declared with
@visibility public.Statement start rules available to PostgreSQL SQL generation.
Values correspond to grammar rule names in PostgreSQL's gram.y.
array_column(\SqlFaker\PostgreSql\Generation\StatementRule::cases(), 'name') // => ['Select', 'Insert', 'Update', 'Delete', 'CreateTable', 'CreateTableAs', 'CreateDomain', 'AlterTable', 'DropTable', 'SimpleStatement']\SqlFaker\PostgreSql\StatementType::Select === \SqlFaker\PostgreSql\Generation\StatementRule::Select // => trueCases
case Select = 'SelectStmt'Public API: explicitly declared with
@visibility public.case Insert = 'InsertStmt'Public API: explicitly declared with
@visibility public.case Update = 'UpdateStmt'Public API: explicitly declared with
@visibility public.case Delete = 'DeleteStmt'Public API: explicitly declared with
@visibility public.case CreateTable = 'CreateStmt'Public API: explicitly declared with
@visibility public.case CreateTableAs = 'CreateAsStmt'Public API: explicitly declared with
@visibility public.case CreateDomain = 'CreateDomainStmt'Public API: explicitly declared with
@visibility public.case AlterTable = 'AlterTableStmt'Public API: explicitly declared with
@visibility public.case DropTable = 'DropStmt'Public API: explicitly declared with
@visibility public.case SimpleStatement = 'stmt'Public API: explicitly declared with
@visibility public.Test cases 6
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 4
Other tests reaching this symbol 2
Relations
Static calls 1
Constant reads 1
- class-const packages/sql-faker/src/PostgreSql/StatementType.php packages/sql-faker/src/PostgreSql/StatementType.php:12